LEDForwardVoltage class

Constructors

LEDForwardVoltage(int value)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

toPointer(int value) Pointer<Int32>

Constants

V_1_7 → const int
V_2_75 → const int
V_3_2 → const int
V_3_9 → const int
V_4_0 → const int
V_4_8 → const int
V_5_0 → const int
V_5_6 → const int