IOMode class

Constructors

IOMode(int value)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

nameOf(int value) String

Constants

LINE_DRIVER_2K2 → const int
LINE_DRIVER_10K → const int
names → const Map<int, String>
OPEN_COLLECTOR_2K2 → const int
OPEN_COLLECTOR_10K → const int
PUSH_PULL → const int