Unit class

Constructors

Unit(int value)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

AMPERE → const int
BOOLEAN → const int
CENTIMETER → const int
DECIBEL → const int
DEGREE_CELCIUS → const int
GAUSS → const int
GRAM → const int
KILOGRAM → const int
KILOPASCAL → const int
LILLIAMPERE → const int
LUX → const int
METER → const int
MILLIMETER → const int
NONE → const int
PERCENT → const int
PH → const int
VOLT → const int
WATT → const int