Voltage class

Constructors

Voltage(int value)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

RANGE_2V → const int
RANGE_5V → const int
RANGE_10mV → const int
RANGE_15V → const int
RANGE_40mV → const int
RANGE_40V → const int
RANGE_200mV → const int
RANGE_312_5mV → const int
RANGE_400mV → const int
RANGE_1000mV → const int
RANGE_AUTO → const int