PhidgetErrorCode class

Constructors

PhidgetErrorCode(int value)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

EPHIDGET_2BIG → const int
EPHIDGET_ACCESS → const int
EPHIDGET_AGAIN → const int
EPHIDGET_BADCONNECTION → const int
EPHIDGET_BADCURRENT → const int
EPHIDGET_BADPASSWORD → const int
EPHIDGET_BADPOWER → const int
EPHIDGET_BADVERSION → const int
EPHIDGET_BUSY → const int
EPHIDGET_CLOSED → const int
EPHIDGET_CONNREF → const int
EPHIDGET_CONNRESET → const int
EPHIDGET_DUPLICATE → const int
EPHIDGET_EOF → const int
EPHIDGET_EXIST → const int
EPHIDGET_FAILSAFE → const int
EPHIDGET_FAULT → const int
EPHIDGET_FBIG → const int
EPHIDGET_HALLSENSOR → const int
EPHIDGET_HOSTUNREACH → const int
EPHIDGET_INTERRUPTED → const int
EPHIDGET_INVALID → const int
EPHIDGET_INVALIDARG → const int
EPHIDGET_INVALIDPACKET → const int
EPHIDGET_IO → const int
EPHIDGET_ISDIR → const int
EPHIDGET_KEEPALIVE → const int
EPHIDGET_MFILE → const int
EPHIDGET_NACK → const int
EPHIDGET_NETUNAVAIL → const int
EPHIDGET_NFILE → const int
EPHIDGET_NODEV → const int
EPHIDGET_NOENT → const int
EPHIDGET_NOMEMORY → const int
EPHIDGET_NOSPC → const int
EPHIDGET_NOTATTACHED → const int
EPHIDGET_NOTCONFIGURED → const int
EPHIDGET_NOTDIR → const int
EPHIDGET_NOTEMPTY → const int
EPHIDGET_OK → const int
EPHIDGET_PERM → const int
EPHIDGET_PIPE → const int
EPHIDGET_POWERCYCLE → const int
EPHIDGET_RESOLV → const int
EPHIDGET_RO → const int
EPHIDGET_ROFS → const int
EPHIDGET_TIMEOUT → const int
EPHIDGET_UNEXPECTED → const int
EPHIDGET_UNKNOWNVAL → const int
EPHIDGET_UNKNOWNVALHIGH → const int
EPHIDGET_UNKNOWNVALLOW → const int
EPHIDGET_UNSUPPORTED → const int
EPHIDGET_WRONGDEVICE → const int
PHIDGET_CHANNEL_ANY → const int
PHIDGET_HUBPORT_ANY → const int
PHIDGET_ISLOCAL_ANY → const int
PHIDGET_ISREMOTE_ANY → const int
PHIDGET_SERIALNUMBER_ANY → const int
PHIDGET_TIMEOUT_DEFAULT → const int
PHIDGET_TIMEOUT_INFINITE → const int
PUNK_BOOL → const int
PUNK_DBL → const double
PUNK_INT32 → const int
PUNK_INT64 → const int